| predict.matchFeat | R Documentation |
predict method for class "matchFeat"
## S3 method for class 'matchFeat' predict(object, newdata, unit = NULL, ...)
object |
an object of class |
newdata |
new dataset of feature vectors |
unit |
unit labels for new data. Only necessary if |
... |
for compatibility with the generic |
The function predict.matchFeat finds the best matching for new feature vectors relative to an existing set of cluster/class centers. If codeobject results from a call to match.gaussmix, the same function is used for prediction (with fixed mean vectors and covariance matrices). In other cases, the function match.template is used for prediction.
A list of class matchFeat with fields
sigmabest matching as set of permutations ((m,n) matrix)
clusterbest matching as cluster indicators ((m,n)-matrix)
objectiveminimum objective value
mumean vector for each class/label ((p,m) matrix)
Vcovariance matrix for each class/label ((p,p,m) array if equal.variance is FALSE, (p,p) matrix otherwise
callfunction call
print.matchFeat, summary.matchFeat
data(optdigits) train.result <- match.bca(optdigits$x[1:900,], optdigits$unit[1:900]) test.result <- predict(train.result, optdigits$x[901:1000,], optdigits$unit[901:1000]) test.result
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.