| print.matchFeat | R Documentation |
print method for class "matchFeat".
## S3 method for class 'matchFeat' print(x,...)
x |
an object of class |
... |
for compatibility with the generic |
The function print.matchFeat concisely displays the information of an object of class "matchFeat". More precisely it shows the
data range, bandwidth used in local polynomial estimation, and key information on SCB and statistical tests.
No return value, called for side effects
predict.matchFeat, summary.matchFeat
data(optdigits) result <- match.bca(optdigits$x, optdigits$unit) print(result)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.