| summary.matchFeat | R Documentation |
summary method for class "matchFeat"
## S3 method for class 'matchFeat' summary(object, ...)
object |
an object of class |
... |
additional arguments; not currently used. |
The function summary.matchFeat displays all fields of a matchFeat object at the exception of x, y, par, nonpar, normscb, and bootscb which are potentially big. It provides information on the function call, data, local polynomial fit, SCB, and statistical tests.
No return value, called for side effects
predict.matchFeat,
print.matchFeat
data(optdigits) result <- match.bca(optdigits$x, optdigits$unit) summary(result)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.