tools:::Rd_package_description("matchFeat")
Author: tools:::Rd_package_author("matchFeat")
Maintainer: tools:::Rd_package_maintainer("matchFeat")
This package serves to match feature vectors across a collection of datasets in a one-to-one fashion. This task is formulated as a multidimensional assignment problem with decomposable costs (MDADC). We propose fast algorithms with time complexity roughly linear in the number \(n\) of datasets and space complexity a small fraction of the data size.
Initialization methods: match.rec (recursive) and match.template (template-based).
Main matching algorithms: match.bca, match.bca.gen (for unbalanced data), and match.kmeans (\(k\)-means matching).
Refinement methods (post-processing): match.2x (pairwise interchange) and match.gaussmix (Gaussian mixture model with permutation constraints).
Degras (2022) "Scalable feature matching across large data collections."
tools:::Rd_expr_doi("10.1080/10618600.2022.2074429")
Wright (2015). Coordinate descent algorithms.
https://arxiv.org/abs/1502.04759
McLachlan and Krishnan (2008). The EM Algorithm and Extensions