Learn R Programming

matchFeat (version 1.0)

print.matchFeat: Print a matchFeat Object

Description

print method for class "matchFeat".

Usage

# S3 method for matchFeat
print(x,...)

Value

No return value, called for side effects

Arguments

x

an object of class "matchFeat".

...

for compatibility with the generic print method; argument not currently used.

Details

The function print.matchFeat concisely displays the information of an object of class "matchFeat". More precisely it shows the data range, bandwidth used in local polynomial estimation, and key information on SCB and statistical tests.

See Also

predict.matchFeat, summary.matchFeat

Examples

Run this code
data(optdigits)
result <- match.bca(optdigits$x, optdigits$unit)
print(result)

Run the code above in your browser using DataLab