for compatibility with the generic print method; argument not currently used.
Details
The function print.matchFeat concisely displays the information of an object of class "matchFeat". More precisely it shows the
data range, bandwidth used in local polynomial estimation, and key information on SCB and statistical tests.