Learn R Programming

matchFeat (version 1.0)

summary.matchFeat: Summarize a matchFeat Object

Description

summary method for class "matchFeat"

Usage

# S3 method for matchFeat
summary(object, ...)

Value

No return value, called for side effects

Arguments

object

an object of class "matchFeat"

...

additional arguments; not currently used.

Details

The function summary.matchFeat displays all fields of a matchFeat object at the exception of x, y, par, nonpar, normscb, and bootscb which are potentially big. It provides information on the function call, data, local polynomial fit, SCB, and statistical tests.

See Also

predict.matchFeat, print.matchFeat

Examples

Run this code
data(optdigits)
result <- match.bca(optdigits$x, optdigits$unit)
summary(result)

Run the code above in your browser using DataLab